package ink.wgink.module.wechat.pay.pojo.v3.refund;

import ink.wgink.module.wechat.pay.enums.RefundStatusEnum;

/**
 * @ClassName: RefundNoticeCiphertext
 * @Description: 退款通知密文
 * @Author: wanggeng
 * @Date: 2022/11/12 00:00
 * @Version: 1.0
 */
public class RefundNoticeCiphertext {

    /**
     * 直连商户号<br/>
     * 直连商户的商户号，由微信支付生成并下发。
     */
    private String mchid;
    /**
     * 商户订单号<br/>
     * 返回的商户订单号
     */
    private String out_trade_no;
    /**
     * 微信支付订单号
     */
    private String transaction_id;
    /**
     * 商户退款单号
     */
    private String out_refund_no;
    /**
     * 微信支付退款单号
     */
    private String refund_id;
    /**
     * 退款状态
     */
    private RefundStatusEnum refund_status;
    /**
     * 退款成功时间
     */
    private String success_time;
    /**
     * 退款入账账户
     */
    private String user_received_account;
    /**
     * 金额信息
     */
    private Amount amount;

    public String getMchid() {
        return mchid == null ? "" : mchid.trim();
    }

    public void setMchid(String mchid) {
        this.mchid = mchid;
    }

    public String getOut_trade_no() {
        return out_trade_no == null ? "" : out_trade_no.trim();
    }

    public void setOut_trade_no(String out_trade_no) {
        this.out_trade_no = out_trade_no;
    }

    public String getTransaction_id() {
        return transaction_id == null ? "" : transaction_id.trim();
    }

    public void setTransaction_id(String transaction_id) {
        this.transaction_id = transaction_id;
    }

    public String getOut_refund_no() {
        return out_refund_no == null ? "" : out_refund_no.trim();
    }

    public void setOut_refund_no(String out_refund_no) {
        this.out_refund_no = out_refund_no;
    }

    public String getRefund_id() {
        return refund_id == null ? "" : refund_id.trim();
    }

    public void setRefund_id(String refund_id) {
        this.refund_id = refund_id;
    }

    public RefundStatusEnum getRefund_status() {
        return refund_status;
    }

    public void setRefund_status(RefundStatusEnum refund_status) {
        this.refund_status = refund_status;
    }

    public String getSuccess_time() {
        return success_time == null ? "" : success_time.trim();
    }

    public void setSuccess_time(String success_time) {
        this.success_time = success_time;
    }

    public String getUser_received_account() {
        return user_received_account == null ? "" : user_received_account.trim();
    }

    public void setUser_received_account(String user_received_account) {
        this.user_received_account = user_received_account;
    }

    public Amount getAmount() {
        return amount;
    }

    public void setAmount(Amount amount) {
        this.amount = amount;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("{");
        sb.append("\"mchid\":\"")
                .append(mchid).append('\"');
        sb.append(",\"out_trade_no\":\"")
                .append(out_trade_no).append('\"');
        sb.append(",\"transaction_id\":\"")
                .append(transaction_id).append('\"');
        sb.append(",\"out_refund_no\":\"")
                .append(out_refund_no).append('\"');
        sb.append(",\"refund_id\":\"")
                .append(refund_id).append('\"');
        sb.append(",\"refund_status\":")
                .append(refund_status);
        sb.append(",\"success_time\":\"")
                .append(success_time).append('\"');
        sb.append(",\"user_received_account\":\"")
                .append(user_received_account).append('\"');
        sb.append(",\"amount\":")
                .append(amount);
        sb.append('}');
        return sb.toString();
    }

    public static class Amount {
        /**
         * 订单金额<br/>
         * 订单总金额，单位为分，只能为整数，详见<a href="https://pay.weixin.qq.com/wiki/doc/api/jsapi.php?chapter=4_2">支付金额</a>
         */
        private Integer total;
        /**
         * 退款金额<br/>
         * 退款金额，币种的最小单位，只能为整数，不能超过原订单支付金额，如果有使用券，后台会按比例退。
         */
        private Integer refund;
        /**
         * 用户支付金额<br/>
         * 用户实际支付金额，单位为分，只能为整数，详见<a href="https://pay.weixin.qq.com/wiki/doc/api/jsapi.php?chapter=4_2">支付金额</a>
         */
        private Integer payer_total;
        /**
         * 用户退款金额<br/>
         * 退款给用户的金额，不包含所有优惠券金额
         */
        private Integer payer_refund;

        public Integer getTotal() {
            return total == null ? 0 : total;
        }

        public void setTotal(Integer total) {
            this.total = total;
        }

        public Integer getRefund() {
            return refund == null ? 0 : refund;
        }

        public void setRefund(Integer refund) {
            this.refund = refund;
        }

        public Integer getPayer_total() {
            return payer_total == null ? 0 : payer_total;
        }

        public void setPayer_total(Integer payer_total) {
            this.payer_total = payer_total;
        }

        public Integer getPayer_refund() {
            return payer_refund == null ? 0 : payer_refund;
        }

        public void setPayer_refund(Integer payer_refund) {
            this.payer_refund = payer_refund;
        }
    }

}
