package ink.wgink.module.wechat.pay.service.v3.impl;

import com.alibaba.fastjson.JSONObject;
import ink.wgink.common.base.DefaultBaseService;
import ink.wgink.exceptions.base.SystemException;
import ink.wgink.module.wechat.pay.enums.PayErrorMsgEnum;
import ink.wgink.module.wechat.pay.pojo.v3.Notice;
import ink.wgink.module.wechat.pay.pojo.v3.PayNoticeCiphertext;
import ink.wgink.module.wechat.pay.service.v3.IPayNoticeService;
import ink.wgink.module.wechat.pay.service.v3.IPayService;
import ink.wgink.module.wechat.pay.utils.v3.AsyncNoticeResultUtil;
import ink.wgink.properties.wechat.pay.v3.PayProperties;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * @ClassName: IPayServiceImpl
 * @Description: 支付
 * @Author: wanggeng
 * @Date: 2021/8/20 8:15 上午
 * @Version: 1.0
 */
@Service
public class PayServiceImpl extends DefaultBaseService implements IPayService {

    @Autowired
    private PayProperties payProperties;
    @Autowired
    private IPayNoticeService payNoticeService;

    @Override
    public void notice(HttpServletRequest request, HttpServletResponse response, String nonce, String timestamp, String wechatpaySignature) throws IOException {
        try {
            Notice notice = AsyncNoticeResultUtil.getNotice(request, nonce, timestamp, wechatpaySignature);
            String noticeCiphertextJsonString = AsyncNoticeResultUtil.getNoticeCiphertext(notice, payProperties.getApiV3Secretkey());
            PayNoticeCiphertext payNoticeCiphertext = JSONObject.parseObject(noticeCiphertextJsonString, PayNoticeCiphertext.class);
            payNoticeService.handle(payNoticeCiphertext);
        } catch (Exception e) {
            LOG.error(e.getMessage(), e);
            if (e instanceof SystemException) {
                AsyncNoticeResultUtil.errorResult(response, PayErrorMsgEnum.SIGN_ERROR_401);
                return;
            }
            AsyncNoticeResultUtil.errorResult(response, PayErrorMsgEnum.ERROR_500);
            return;
        }
        AsyncNoticeResultUtil.successResult(response);
    }


}
